from typer import echo, style, colors


def error_message(description):
    error = style(description, fg=colors.RED)
    echo(f"Usage: kiki.py [OPTIONS] PDF\nTry 'kiki.py --help' for help.\n\nError: {error}")
    exit(-1)



import os
import typer
from .utils import error_message
from .pdf_handler import file_pdf, url_pdf

app = typer.Typer(add_completion=False)


@app.command('github')
def github():
    """open github repo for Kiki"""

    typer.echo('Opening GitHub Repo...')
    typer.launch('https://github.com/VijayStroup/Kiki')


@app.command('get')
def get(
    pdf: str = typer.Argument(..., help='url or file of pdf'),
    filename: str = typer.Option('kiki', help='name of output file without extension')
):
    """get audio from pdf"""

    # check to make sure pdf arg is a pdf file
    if not pdf[-3:] == 'pdf':
        error_message(f"Invalid file '{pdf}'. Must be a pdf file.")

    # check if pdf is file or url
    if os.path.isfile(pdf):
        file_pdf(pdf, filename)
    else:
        url_pdf(pdf, filename)

    typer.echo(f'Your audio file is now available at {filename}.mp3')


def main():
    app()



from setuptools import setup, find_packages


def get_requirements():
    with open('requirements.txt') as f:
        data = f.read()
        return data.split('\n')


def get_long_desc():
    with open('README.md', 'r') as f:
        return f.read()


setup(
    name = 'kiki',
    version = '1.0',
    description = 'pdf text-to-speech',
    long_description = get_long_desc(),
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/VijayStroup/Kiki',
    author = 'Vijay Stroup',
    author_email = 'vijay@vijaystroup.com',
    packages = find_packages(),
    include_package_data = True,
    install_requires = get_requirements(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points = """
        [console_scripts]
        kiki = kiki.kiki:main
    """
)



from os import remove
from gtts import gTTS
from PyPDF2 import PdfFileReader
from typer import progressbar
import requests
from .utils import error_message


def download(pdf, file_out):
    """function that takes a pdf object and converts it to an audio file"""

    with progressbar(length=pdf.getNumPages(), label='Downloading') as progress:
        with open(f'{file_out}.mp3', 'wb') as f:
            for page in progress:
                text = pdf.getPage(page).extractText()
                if text:
                    tts = gTTS(text)
                    tts.write_to_fp(f)


def file_pdf(file_name, file_out):
    """create pdf object from file and download audio"""

    pdf = PdfFileReader(file_name, strict=False)
    download(pdf, file_out)


def url_pdf(url, file_out):
    """make pdf object from beautifulsoup and download audio"""

    file_name = 'kiki_temp.pdf'

    try:
        r = requests.get(url, timeout=3)
        if r.status_code == 200:
            with open(file_name, 'wb') as f:
                f.write(r.content)
            pdf = PdfFileReader(file_name, strict=False)
            download(pdf, file_out)
            remove(file_name)
        else:
            error_message(f'{url} is invalid.')
    except requests.exceptions.Timeout:
        error_message(f'Request for {url} timed out.')
    except requests.exceptions.RequestException as e:
        error_message(f'Request for {url} is invalid.')
